From 683f19a8632a197353cc40068a9a7a0de8ed727b Mon Sep 17 00:00:00 2001
From: zzzz <690498789@qq.com>
Date: Thu, 18 Apr 2024 12:53:22 +0800
Subject: [PATCH] 1
---
src/page/newUser/index.vue | 67 ++++++++++++++++++++-------------
1 files changed, 41 insertions(+), 26 deletions(-)
diff --git a/src/page/newUser/index.vue b/src/page/newUser/index.vue
index 3e7f5fd..1f0e37b 100644
--- a/src/page/newUser/index.vue
+++ b/src/page/newUser/index.vue
@@ -33,21 +33,19 @@
<i @click="xy = !xy" class="iconfont xy"></i>
</div>
<div class="number-all">
- <showHide :text="userInfo.totalAssets" :flg="xy" />
+ <showHide :text="asstesAll" :flg="xy" />
</div>
</van-col>
</van-row>
<van-row style="margin-top: 18px">
<div
- class="van-col van-col--8"
+ class="van-col van-col--12"
style="margin-top: 10px"
v-for="item in listAsstes"
:key="item.accectType"
>
<div class="content-title DINPro">
- {{
- item.accectType === "US" ? $t("美股總資產") : $t("馬股總資產")
- }}
+ {{ item.title3 }}
({{ item.symbolCode }})
</div>
<div>
@@ -104,7 +102,7 @@
:name="item.title"
>
<ul class="money">
- <li>
+ <li style="text-align: left">
<div class="li-title">
{{ item.title1 }}({{ item.symbolCode }})
</div>
@@ -151,31 +149,43 @@
xy: true,
listAsstes: [
{
- title: this.$t("美股資產"),
- title1: this.$t("美股可用"),
- title2: this.$t("美股冻结"),
- accectType: "US",
- symbol: "$",
- symbolCode: "USD",
+ title: this.$t("印股資產"),
+ title3: this.$t("印股總資產"),
+ title1: this.$t("印股可用"),
+ title2: this.$t("印股冻结"),
+ accectType: "IN",
+ symbolCode: "INR",
+ symbol: "₹",
},
// {
// title: this.$t("印股資產"),
// title1: this.$t("印股可用"),
// title2: this.$t("印股冻结"),
// accectType: "IN",
// symbol: "RM",
// symbolCode: "MYR",
// },
- {
- title: this.$t("馬股資產"),
- title1: this.$t("馬股可用"),
- title2: this.$t("馬股冻结"),
- accectType: "MAS",
- symbol: "RM",
- symbolCode: "MYR",
- },
+ // {
+ // title: this.$t("港股资产"),
+ // title3: this.$t("港股總資產"),
+ // title1: this.$t("港股可用"),
+ // title2: this.$t("港股冻结"),
+ // accectType: "HK",
+ // symbol: "HK$",
+ // symbolCode: "HKD",
+ // },
],
- active: this.$t("美股資產"),
+ active: this.$t("印股資產"),
name: "",
selectUserFlag: true,
settingDialog: false,
@@ -185,6 +195,7 @@
userInfo: [],
onlineService: "",
moneyList: [],
+ asstesAll: "0.00",
};
},
created() {
@@ -211,7 +222,9 @@
}
});
});
- console.log(this.listAsstes);
+
+ const arr = data.data.filter((item) => item.accectType === "ALL");
+ this.asstesAll = arr[0].totalMoneyUSD;
}
},
tabsChange(e) {
@@ -488,6 +501,8 @@
color: #2d2f3c;
}
.li-USDT {
+ min-width: 180px;
+ text-align: right;
font-style: normal;
font-weight: 500;
font-size: 0.37333rem;
@@ -151,31 +149,43 @@
},
// {
- // title: this.$t("印股資產"),
- // title1: this.$t("印股可用"),
- // title2: this.$t("印股冻结"),
- // accectType: "IN",
+ // title: this.$t("美股資產"),
+ // title3: this.$t("美股總資產"),
+ // title1: this.$t("美股可用"),
+ // title2: this.$t("美股冻结"),
+ // accectType: "US",
+ // symbol: "$",
+ // symbolCode: "USD",
+ // },
+ // {
+ // title: this.$t("馬股資產"),
+ // title3: this.$t("馬股總資產"),
+ // title1: this.$t("馬股可用"),
+ // title2: this.$t("馬股冻结"),
+ // accectType: "MAS",
// symbol: "RM",
// symbolCode: "MYR",
--
Gitblit v1.9.3